@@ -6,18 +6,19 @@ use Sys::Hostname;
 use FindBin;
 
 my $force='';
-$force=' --force' if $ARGV[0] && $ARGV[0] eq 'force';
+$force=' --force' if $ARGV[0] && $ARGV[0] =~/force/;
 
 my $perl=$^X;
 my $hostname=hostname();
 my $path=$FindBin::Bin;
 my $lib=$path."/../lib";
-my ($cpan,$lint,$site);
+my ($cpan,$lint,$site,$yaml);
 
 if ($hostname =~/hexten/) {
     $cpan='/home2/no-backup/CPAN/cpan.hexten.net/htdocs/';
     $lint='/home/domm/Module-CPANTS-Analyse/bin/cpants_lint.pl';
     $site='/home/domm/Module-CPANTS-Site/';
+    $yaml='/home/domm/Module-CPANTS-ProcessCPAN/yaml/';
 
     $ENV{CPANTS_USER}='cpants';
     unless ($ENV{CPANTS_PWD}) {
@@ -30,11 +31,15 @@ if ($hostname =~/hexten/) {
     
 } else {
     $cpan='/home/minicpan';
-    $lint='/home/domm/perl/Module-CPANTS-Analyse/bin/cpants_lint.pl';
-    $site='/home/domm/perl/Module-CPANTS-Site/';
+    $lint='/home/domm/perl/cpants/Module-CPANTS-Analyse/bin/cpants_lint.pl';
+    $site='/home/domm/perl/cpants/Module-CPANTS-Site/';
+    $yaml='/home/domm/perl/cpants/Module-CPANTS-ProcessCPAN/yaml/';
 }
 
-system("$perl -I$lib $path/analyse_cpan.pl --cpan $cpan --lint $lint $force");
+my $yaml_in=$yaml.'in/';
+my $yaml_out=$yaml.'out/';
+system("$perl -I$lib $path/analyse_cpan.pl --cpan $cpan --lint $lint --dir $yaml_in $force");
+system("$perl -I$lib $path/process_yaml.pl --cpan $cpan --dir $yaml");
 system($perl,"-I$lib", $path."/run_complex_db_stuff.pl",$cpan);
 system($perl,"-I$lib", $path."/update_authors.pl",$cpan);
 system($perl,"-I$lib", $path."/make_graphs.pl",$site."root/static/");
