@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw(DBIx::Class);
 
-__PACKAGE__->load_components(qw(PK::Auto::Pg Core));
+__PACKAGE__->load_components(qw(PK::Auto Core));
 __PACKAGE__->table('author');
 __PACKAGE__->add_columns(qw(id pauseid name email average_kwalitee num_dists rank prev_av_kw prev_rank));
 
