@@ -4,24 +4,28 @@ use warnings;
 
 use Module::CPANTS::Analyse;
 use Module::CPANTS::DB;
+use Module::CPANTS::DBHistory;
 use Module::CPANTS::Kwalitee;
+use Module::CPANTS::ProcessCPAN::ConfigData;
 use Data::Dumper;
 use base qw(Class::Accessor);
 use Carp;
 use File::Spec::Functions qw(catdir catfile rel2abs);
 use Parse::CPAN::Packages;
+use YAML::Syck qw(LoadFile);
+use FindBin;
+use File::Copy;
 
-use vars qw($VERSION);
-$VERSION=0.64;
+use version; our $VERSION=qv('0.70');
 
-__PACKAGE__->mk_accessors(qw(cpan lint force run prev_run _db));
+__PACKAGE__->mk_accessors(qw(cpan lint force run prev_run _db _db_hist process_dir out_dir));
 
 sub new {
     my ($class,$cpan,$lint)=@_;
 
     my $me=bless {},$class;
-    $me->cpan(rel2abs($cpan));
-    $me->lint(rel2abs($lint));
+    $me->cpan(rel2abs($cpan)) if $cpan;
+    $me->lint(rel2abs($lint)) if $lint;
     return $me;
 }
 
@@ -29,7 +33,7 @@ sub start_run {
     my $me=shift;
 
     my $mck=Module::CPANTS::Kwalitee->new;
-    my $total_kwalitee=scalar @{$mck->get_indicators};
+    my $total_kwalitee=$mck->total_kwalitee;
     
     # prev run
     my @prev=$me->db->resultset('Run')->search(
@@ -42,13 +46,19 @@ sub start_run {
     $me->prev_run($prev[0]);
         
     my $run=$me->db->resultset('Run')->create({
-        version=>$Module::CPANTS::Analyse::VERSION,
+        mcanalyse_version=>$Module::CPANTS::Analyse::VERSION,
+        mcprocess_version=>$Module::CPANTS::ProcessCPAN::VERSION,
+        available_kwalitee=>$mck->available_kwalitee,
+        total_kwalitee=>$mck->total_kwalitee,
         date=>scalar localtime,
-        available_kwalitee=>$total_kwalitee,
     });
     $me->run($run);
-
     
+    my %for_history=map {$_=>$run->$_} qw(id mcanalyse_version mcprocess_version available_kwalitee total_kwalitee date);
+    $me->db_hist->resultset('Run')->create(
+        \%for_history    
+    );
+
     return $me;
 }
 
@@ -56,53 +66,69 @@ sub process_cpan {
     my $me=shift;
     
     my $p=Parse::CPAN::Packages->new($me->cpan_02packages);
-    my $db=$me->db;
     my $lint=$me->lint;
-    my $run=$me->run;
-     
+    my $analysed=$me->yaml_analysed;
+
     foreach my $dist (sort {$a->dist cmp $b->dist} $p->latest_distributions) {
         my $vname=$dist->distvname;
-       
-        my $exists=$db->resultset('Dist')->find({dist=>$dist->dist});
-        if ($exists) {
-            # check version
-            if ($exists->vname && $vname eq $exists->vname) {
-                if ($me->force) {
-                    print "forced reindex of ".$dist->dist." (".$dist->version." )\n";
-                    $me->make_dist_history($exists); 
-                    $exists->delete;
-                } else {
-                    next;
-                }
-            } else {
-                print "new version of ".($dist->dist || '?')." (".($exists->version || '?')." -> ".($dist->version || '?')." )\n";
-                $me->make_dist_history($exists); 
-                $exists->delete;
-            }
-        }
-        
         next if $vname=~/^perl[-\d]/;
         next if $vname=~/^ponie-/;
         next if $vname=~/^Perl6-Pugs/;
         next if $vname=~/^parrot-/;
         next if $vname=~/^Bundle-/;
-        
+
+        if (-e catfile($analysed,$vname.'.yml')) {
+            if ($me->force) {
+                print "forced reindex of ".$dist->dist." (".$dist->version." )\n";
+            }
+            else {
+                print "skipping ".$dist->dist." (".$dist->version." )\n";
+                next;
+            }
+        }
+        else {
+            print "new version of ".$dist->dist." (".$dist->version." )\n";
+        }
+    
         print "analyse $vname\n";
-       
-        # todo: store immediatly in DB so we can catch "bad" dists that fail
-        # completely
-        
         my $file=$me->cpan_path_to_dist($dist->prefix);
         
-        # call cpants_lint.pl (fork because I think it's easier)
-        my $lintresult=`$^X $lint -d $file`;
+        # call cpants_lint.pl
+        system("$^X $lint --yaml --to_file --dir $analysed $file");
+    }
+}
+
+sub process_yaml {
+    my $me=shift;
+    
+    my $p=Parse::CPAN::Packages->new($me->cpan_02packages);
+    my $db=$me->db;
+    my $run=$me->run;
+    
+    my $in_dir=$me->yaml_analysed;
+    my $out_dir=$me->yaml_processed;
+    
+    opendir(my $IN,$in_dir) || die "Cannot open YAML dir $in_dir: $!";
+    while (my $file=readdir $IN) {
+        next unless $file=~/\.yml$/;
+        my $absfile=catfile($in_dir,$file);
+        copy($absfile,catfile($out_dir,$file));
         my $data;
-        eval {
-            my $VAR1;
-            eval $lintresult;
-            $data=$VAR1;
-        };
-        
+        eval { $data=LoadFile($absfile) };
+        if ($@) {
+            print "Cannot parse YAML $absfile: $@";
+            next;
+        }
+
+        print $data->{dist}."\n";
+
+        # remove old data from this dist
+        my $exists=$db->resultset('Dist')->find({dist=>$data->{dist}});
+        if ($exists) {
+            $me->make_dist_history($exists); 
+            $exists->delete;
+        }
+
         # remove data that references other tables;
         my $kwalitee=$data->{kwalitee};
         my $modules=$data->{modules};
@@ -121,7 +147,7 @@ sub process_cpan {
             $me->make_author_history($db_author);
             
             $db_dist=$db_author->add_to_dists({ 
-                dist=>$dist->dist,
+                dist=>$data->{dist},
                 run=>$run->id,
             })
         };
@@ -136,15 +162,19 @@ sub process_cpan {
             foreach my $m (@$modules) {
                 $db_dist->add_to_modules($m);
             }
-            foreach my $p (@$prereq) {
-                $db_dist->add_to_prereq($p);
+            foreach my $pq (@$prereq) {
+                $db_dist->add_to_prereq($pq);
             }
             foreach my $u (values %$uses) {
                 $db_dist->add_to_uses($u);
             }
         };
         if ($@) {
-            $db_dist->cpants_errors($db_dist->cpants_errors."\nDB:\n$@");
+            my $from_cpants='';
+            if (my $old=$db_dist->cpants_errors) {
+                $from_cpants="$old\n";
+            }
+            $db_dist->cpants_errors(join('',$from_cpants,"DB: $@"));
             $db->txn_rollback;
             $kwalitee->{no_cpants_errors}=0;
         } else {
@@ -161,21 +191,24 @@ sub process_cpan {
         if ($@) {
             my $e=$@;
             $db->txn_rollback;
-            croak $dist->dist." DB kwalitee error: $e";
+            croak $data->{dist}." DB kwalitee error: $e";
         } else {
             $db->txn_commit;
         }
+        unlink($absfile);
     }
 
     # dump old dists
     my @distributions=$p->distributions;
-    my %dists=map {$_->dist => 1}  @distributions;
+    my %dists=map {$_->dist => 1} grep { $_->dist }   @distributions;
 
     my $rs=$db->resultset('Dist')->search;
-    while (my $in_db=$rs->next) {
-        unless ($dists{$in_db->dist}) {
-            print $in_db->dist." not on CPAN anymore, deleted from DB\n";
-            $in_db->delete;
+    if ($rs) {
+        while (my $in_db=$rs->next) {
+            unless ($dists{$in_db->dist}) {
+                print $in_db->dist." not on CPAN anymore, deleted from DB\n";
+                $in_db->delete;
+            }
         }
     }
 }
@@ -184,17 +217,15 @@ sub make_author_history {
     my $me=shift;
     my $author=shift;
     
-    my $db=$me->db;
+    my $dbhist=$me->db_hist;
 
-    $db->txn_begin;
-    $db->resultset('AuthHist')->create({
+    $dbhist->resultset('Author')->create({
         run=>$me->run->id,
         author=>$author->id,
         average_kwalitee=>$author->average_kwalitee || 0,
         num_dists=>$author->num_dists || 0,
         rank=>$author->rank || 0,
     });
-    $db->txn_commit;
     
     # set conveniece fields in current author
     $author->prev_av_kw($author->average_kwalitee || 0);
@@ -207,7 +238,7 @@ sub make_dist_history {
     
     my $old_kw=$dist->kwalitee ? $dist->kwalitee->kwalitee : 0;
     
-    $me->db->resultset('DistHist')->find_or_create({
+    $me->db_hist->resultset('Dist')->find_or_create({
         run=>$me->run->id,
         distname=>$dist->dist,
         version=>$dist->version,
@@ -220,8 +251,16 @@ sub db {
     my $me=shift;
     return $me->_db if $me->_db;
    
-    my $name = $INC{'Test/More.pm'} ? 'test_cpants' : 'cpants';
-    return $me->_db(Module::CPANTS::DB->connect('dbi:Pg:dbname='.$name,$ENV{CPANTS_USER},$ENV{CPANTS_PWD}));
+    my $name = catfile($me->root,qw(sqlite cpants.db));
+    return $me->_db(Module::CPANTS::DB->connect('dbi:SQLite:dbname='.$name));
+}
+
+sub db_hist {
+    my $me=shift;
+    return $me->_db_hist if $me->_db_hist;
+   
+    my $name = catfile($me->root,qw(sqlite cpants_history.db));
+    return $me->_db_hist(Module::CPANTS::DBHistory->connect("dbi:SQLite:dbname=$name"));
 }
 
 sub cpan_01mailrc {
@@ -240,6 +279,18 @@ sub cpan_path_to_dist {
     return catfile($me->cpan,'authors','id',$prefix);
 }
 
+=head2 Accessors to various directories
+
+=cut
+
+sub root {
+    my $me=shift;
+    return Module::CPANTS::ProcessCPAN::ConfigData->config('root');
+}
+
+sub yaml_analysed { return catdir(shift->root,qw(yaml analysed)) }
+sub yaml_processed { return catdir(shift->root,qw(yaml processed)) }
+
 1;
 
 __END__
